"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("./errors");
const logging_1 = require("@hibas123/logging");
function RequestError(ctx, next) {
    function reply(status, message) {
        ctx.status = status;
        ctx.body = message;
    }
    return next()
        .then(() => {
        if (ctx.status === errors_1.HttpStatusCode.NOT_FOUND) {
            reply(errors_1.HttpStatusCode.NOT_FOUND, "Not found");
        }
    })
        .catch((error) => {
        let message = "Internal server error";
        let status = errors_1.HttpStatusCode.INTERNAL_SERVER_ERROR;
        if (typeof error === "string") {
            message = error;
        }
        else if (!(error instanceof errors_1.HttpError)) {
            logging_1.default.error(error);
            message = error.message;
        }
        else {
            if (error.status === errors_1.HttpStatusCode.INTERNAL_SERVER_ERROR) {
                //If internal server error log whole error
                logging_1.default.error(error);
            }
            else {
                message = error.message.split("\n", 1)[0];
                logging_1.default.error(message);
            }
            status = error.status;
        }
        reply(status, message);
    });
}
exports.default = RequestError;
//# sourceMappingURL=error.js.map